@@ -39,7 +39,7 @@ class KURL;
  */
 class BookmarkSelector : public URLButton
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
