@@ -49,8 +49,8 @@ DolphinDetailsView::DolphinDetailsView(DolphinView* parent) :
     m_rubber(0)
 {
     m_resizeTimer = new TQTimer(this);
-    connect(m_resizeTimer, TQT_SIGNAL(timeout()),
-            this, TQT_SLOT(updateColumnsWidth()));
+    connect(m_resizeTimer, TQ_SIGNAL(timeout()),
+            this, TQ_SLOT(updateColumnsWidth()));
 
     setAcceptDrops(true);
     setSelectionMode(KFile::Extended);
@@ -63,30 +63,30 @@ DolphinDetailsView::DolphinDetailsView(DolphinView* parent) :
 
     Dolphin& dolphin = Dolphin::mainWin();
 
-    connect(this, TQT_SIGNAL(onItem(TQListViewItem*)),
-            this, TQT_SLOT(slotOnItem(TQListViewItem*)));
-    connect(this, TQT_SIGNAL(onViewport()),
-            this, TQT_SLOT(slotOnViewport()));
-    connect(this, TQT_SIGNAL(contextMenuRequested(TQListViewItem*, const TQPoint&, int)),
-            this, TQT_SLOT(slotContextMenuRequested(TQListViewItem*, const TQPoint&, int)));
-    connect(this, TQT_SIGNAL(selectionChanged()),
-            &dolphin, TQT_SLOT(slotSelectionChanged()));
-    connect(&dolphin, TQT_SIGNAL(activeViewChanged()),
-            this, TQT_SLOT(slotActivationUpdate()));
-    connect(this, TQT_SIGNAL(itemRenamed(TQListViewItem*, const TQString&, int)),
-            this, TQT_SLOT(slotItemRenamed(TQListViewItem*, const TQString&, int)));
-    connect(this, TQT_SIGNAL(dropped(TQDropEvent*, const KURL::List&, const KURL&)),
-            parent, TQT_SLOT(slotURLListDropped(TQDropEvent*, const KURL::List&, const KURL&)));
+    connect(this, TQ_SIGNAL(onItem(TQListViewItem*)),
+            this, TQ_SLOT(slotOnItem(TQListViewItem*)));
+    connect(this, TQ_SIGNAL(onViewport()),
+            this, TQ_SLOT(slotOnViewport()));
+    connect(this, TQ_SIGNAL(contextMenuRequested(TQListViewItem*, const TQPoint&, int)),
+            this, TQ_SLOT(slotContextMenuRequested(TQListViewItem*, const TQPoint&, int)));
+    connect(this, TQ_SIGNAL(selectionChanged()),
+            &dolphin, TQ_SLOT(slotSelectionChanged()));
+    connect(&dolphin, TQ_SIGNAL(activeViewChanged()),
+            this, TQ_SLOT(slotActivationUpdate()));
+    connect(this, TQ_SIGNAL(itemRenamed(TQListViewItem*, const TQString&, int)),
+            this, TQ_SLOT(slotItemRenamed(TQListViewItem*, const TQString&, int)));
+    connect(this, TQ_SIGNAL(dropped(TQDropEvent*, const KURL::List&, const KURL&)),
+            parent, TQ_SLOT(slotURLListDropped(TQDropEvent*, const KURL::List&, const KURL&)));
 
     TQClipboard* clipboard = TQApplication::clipboard();
-    connect(clipboard, TQT_SIGNAL(dataChanged()),
-            this, TQT_SLOT(slotUpdateDisabledItems()));
+    connect(clipboard, TQ_SIGNAL(dataChanged()),
+            this, TQ_SLOT(slotUpdateDisabledItems()));
 
     TQHeader* viewHeader = header();
     viewHeader->setResizeEnabled(false);
     viewHeader->setMovingEnabled(false);
-    connect(viewHeader, TQT_SIGNAL(clicked(int)),
-            this, TQT_SLOT(slotHeaderClicked(int)));
+    connect(viewHeader, TQ_SIGNAL(clicked(int)),
+            this, TQ_SLOT(slotHeaderClicked(int)));
 
     setMouseTracking(true);
     setDefaultRenameAction(TQListView::Accept);
@@ -378,7 +378,7 @@ void DolphinDetailsView::contentsMousePressEvent(TQMouseEvent* event)
     if ((item != 0) && isOnFilename(item, pos)) {
         KFileDetailView::contentsMousePressEvent(event);
     }
-    else if (event->button() == Qt::LeftButton) {
+    else if (event->button() == TQt::LeftButton) {
         const ButtonState keyboardState = TDEApplication::keyboardMouseState();
         const bool isSelectionActive = (keyboardState & ShiftButton) ||
                                        (keyboardState & ControlButton);
@@ -425,8 +425,8 @@ void DolphinDetailsView::contentsMouseReleaseEvent(TQMouseEvent* event)
     }
 
     if (m_scrollTimer != 0) {
-        disconnect(m_scrollTimer, TQT_SIGNAL(timeout()),
-                    this, TQT_SLOT(slotAutoScroll()));
+        disconnect(m_scrollTimer, TQ_SIGNAL(timeout()),
+                    this, TQ_SLOT(slotAutoScroll()));
         m_scrollTimer->stop();
         delete m_scrollTimer;
         m_scrollTimer = 0;
@@ -465,7 +465,7 @@ void DolphinDetailsView::drawRubber()
 
     TQPoint point(m_rubber->x(), m_rubber->y());
     point = contentsToViewport(point);
-    style().tqdrawPrimitive(TQStyle::PE_FocusRect, &p,
+    style().drawPrimitive(TQStyle::PE_FocusRect, &p,
                           TQRect(point.x(), point.y(), m_rubber->width(), m_rubber->height()),
                           colorGroup(), TQStyle::Style_Default, colorGroup().base());
     p.end();
@@ -499,7 +499,7 @@ void DolphinDetailsView::slotActivationUpdate()
     TQObject* object = 0;
     while ((object = it.current()) != 0) {
         if (object->inherits("TQWidget")) {
-            TQWidget* widget = TQT_TQWIDGET(object);
+            TQWidget* widget = static_cast<TQWidget*>(object);
             widget->update();
         }
         ++it;
@@ -582,14 +582,14 @@ void DolphinDetailsView::slotAutoScroll()
     if (scroll) {
         if (m_scrollTimer == 0) {
             m_scrollTimer = new TQTimer( this );
-            connect(m_scrollTimer, TQT_SIGNAL(timeout()),
-                    this, TQT_SLOT(slotAutoScroll()));
+            connect(m_scrollTimer, TQ_SIGNAL(timeout()),
+                    this, TQ_SLOT(slotAutoScroll()));
             m_scrollTimer->start(100, false);
         }
     }
     else if (m_scrollTimer != 0) {
-        disconnect(m_scrollTimer, TQT_SIGNAL(timeout()),
-                   this, TQT_SLOT(slotAutoScroll()));
+        disconnect(m_scrollTimer, TQ_SIGNAL(timeout()),
+                   this, TQ_SLOT(slotAutoScroll()));
         m_scrollTimer->stop();
         delete m_scrollTimer;
         m_scrollTimer = 0;
