@@ -35,7 +35,7 @@ class TQCheckBox;
  */
 class GeneralSettingsPage : public SettingsPageBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
