@@ -36,7 +36,7 @@ RenameDialog::RenameDialog(const KURL::List& items) :
     topLayout->setMargin(KDialog::marginHint());
 
     const int itemCount = items.count();
-    TQLabel* editLabel = new TQLabel(i18n("Rename the %n selected items to:", "Rename the %n selected items to:", itemCount),
+    TQLabel* editLabel = new TQLabel(i18n("Rename the %n selected item to:", "Rename the %n selected items to:", itemCount),
                                    plainPage());
 
     m_lineEdit = new KLineEdit(plainPage());
