@@ -54,7 +54,7 @@ class KFileItem;
 */
 class URLNavigator : public TQHBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
