@@ -55,7 +55,7 @@ ViewPropertiesDialog::ViewPropertiesDialog(DolphinView* dolphinView) :
     TQVBoxLayout* topLayout = new TQVBoxLayout(plainPage(), 0, spacingHint());
 
     // create 'Properties' group containing view mode, sorting, sort order and show hidden files
-    TQGroupBox* propsGroup = new TQGroupBox(2, Qt::Horizontal, i18n("Properties"), plainPage());
+    TQGroupBox* propsGroup = new TQGroupBox(2, TQt::Horizontal, i18n("Properties"), plainPage());
     propsGroup->setSizePolicy(sizePolicy);
     propsGroup->setMargin(margin);
 
@@ -93,7 +93,7 @@ ViewPropertiesDialog::ViewPropertiesDialog(DolphinView* dolphinView) :
 
     // create 'Apply view properties to:' group
     TQButtonGroup* buttonGroup = new TQButtonGroup(3,
-                                                 Qt::Vertical,
+                                                 TQt::Vertical,
                                                  i18n("Apply view properties to:"),
                                                  plainPage());
     buttonGroup->setSizePolicy(sizePolicy);
@@ -118,20 +118,20 @@ ViewPropertiesDialog::ViewPropertiesDialog(DolphinView* dolphinView) :
     topLayout->addWidget(propsGroup);
     topLayout->addWidget(buttonGroup);
 
-    connect(m_viewMode, TQT_SIGNAL(activated(int)),
-            this, TQT_SLOT(slotViewModeChanged(int)));
-    connect(m_sorting, TQT_SIGNAL(activated(int)),
-            this, TQT_SLOT(slotSortingChanged(int)));
-    connect(m_sortOrder, TQT_SIGNAL(activated(int)),
-            this, TQT_SLOT(slotSortOrderChanged(int)));
-    connect(m_showHiddenFiles, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotShowHiddenFilesChanged()));
-    connect(m_applyToCurrentFolder, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotApplyToCurrentFolder()));
-    connect(m_applyToSubFolders, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotApplyToSubFolders()));
-    connect(m_applyToAllFolders, TQT_SIGNAL(clicked()),
-            this, TQT_SLOT(slotApplyToAllFolders()));
+    connect(m_viewMode, TQ_SIGNAL(activated(int)),
+            this, TQ_SLOT(slotViewModeChanged(int)));
+    connect(m_sorting, TQ_SIGNAL(activated(int)),
+            this, TQ_SLOT(slotSortingChanged(int)));
+    connect(m_sortOrder, TQ_SIGNAL(activated(int)),
+            this, TQ_SLOT(slotSortOrderChanged(int)));
+    connect(m_showHiddenFiles, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotShowHiddenFilesChanged()));
+    connect(m_applyToCurrentFolder, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotApplyToCurrentFolder()));
+    connect(m_applyToSubFolders, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotApplyToSubFolders()));
+    connect(m_applyToAllFolders, TQ_SIGNAL(clicked()),
+            this, TQ_SLOT(slotApplyToAllFolders()));
 }
 
 ViewPropertiesDialog::~ViewPropertiesDialog()
